<div align="center">
    <img src="../../docs/images/logo-title.png" height="80px">
    <h3>The Graph Of LIfe Library.</h3>
</div>


## What is in this folder? 

- ✅ `encoder_manager.py`: encoder manager to manage the positional encoders and pool them at the correct level as input to the gnns
- ✅ `global_architectures.py`: `FullGraphNetwork`, architecture to run all the gnn layers
- `pyg_architectures.py`: `FeedForwardPyg`, base class for different pyg layers